TwitchCustomReward class
- Annotations
-
- @freezed
Constructors
- TwitchCustomReward({required String broadcasterName, required String? broadcasterLogin, required String broadcasterId, required String id, required TwitchCustomRewardImage? image, required String backgroundColor, required bool isEnabled, required int cost, required String title, required String prompt, required bool isUserInputRequired, required TwitchMaxPerStream maxPerStreamSetting, required TwitchMaxPerUserPerStreamSetting maxPerUserPerStreamSetting, required TwitchGlobalCooldownSetting globalCooldownSetting, required bool isPaused, required bool isInStock, required TwitchCustomRewardImage defaultImage, required bool shouldRedemptionsSkipRequestQueue, required int? redemptionsRedeemedCurrentStream, required String? cooldownExpiresAt})
-
constfactory
-
TwitchCustomReward.fromJson(Map<
String, dynamic> json) -
factory
Properties
- backgroundColor → String
-
Custom background color for the reward. Format: Hex with # prefix.
Example:
#00E5CB.no setterinherited - broadcasterId → String
-
Display name of the channel the reward is for.
no setterinherited
- broadcasterLogin → String?
-
Broadcaster’s user login name.
no setterinherited
- broadcasterName → String
-
ID of the channel the reward is for.
no setterinherited
- cooldownExpiresAt → String?
-
Timestamp of the cooldown expiration. Null if the reward isn’t on
cooldown.
no setterinherited
-
copyWith
→ $TwitchCustomRewardCopyWith<
TwitchCustomReward> -
no setterinherited
- cost → int
-
The cost of the reward.
no setterinherited
- defaultImage → TwitchCustomRewardImage
-
Set of default images of 1x, 2x and 4x sizes for the reward.
no setterinherited
- globalCooldownSetting → TwitchGlobalCooldownSetting
-
Whether a cooldown is enabled and what the cooldown is.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the reward.
no setterinherited
- image → TwitchCustomRewardImage?
-
Set of custom images of 1x, 2x and 4x sizes for the reward can be null if
no images have been uploaded.
no setterinherited
- isEnabled → bool
-
Is the reward currently enabled, if false the reward won’t show up to
viewers.
no setterinherited
- isInStock → bool
-
Is the reward currently in stock, if false viewers can’t redeem.
no setterinherited
- isPaused → bool
-
Is the reward currently paused, if true viewers can’t redeem.
no setterinherited
- isUserInputRequired → bool
-
Does the user need to enter information when redeeming the reward.
no setterinherited
- maxPerStreamSetting → TwitchMaxPerStream
-
Whether a maximum per stream is enabled and what the maximum is.
no setterinherited
- maxPerUserPerStreamSetting → TwitchMaxPerUserPerStreamSetting
-
Whether a maximum per user per stream is enabled and what the maximum is.
no setterinherited
- prompt → String
-
The prompt for the viewer when they are redeeming the reward.
no setterinherited
- redemptionsRedeemedCurrentStream → int?
-
The number of redemptions redeemed during the current live stream. Counts
against the max_per_stream_setting limit. Null if the broadcasters stream
isn’t live or max_per_stream_setting isn’t enabled.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldRedemptionsSkipRequestQueue → bool
-
Should redemptions be set to FULFILLED status immediately when redeemed
and skip the request queue instead of the normal UNFULFILLED status.
no setterinherited
- title → String
-
The title of the reward.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited