TwitchExtensionTransaction class
Constructors
-
TwitchExtensionTransaction({required String id, required DateTime timestamp, required String broadcasterId, required String broadcasterLogin, required String broadcasterName, required String userId, required String userLogin, required String userName, required TwitchExtensionTransactionProductType productType, required ProductData productData, String? domain, bool? broadcast, String? expiration})
-
const
factory
-
TwitchExtensionTransaction.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
broadcast
→ bool?
-
Flag that denotes whether or not the data was sent over the extension
pubsub to all instances of the extension.
no setterinherited
-
broadcasterId
→ String
-
Twitch User ID of the channel the transaction occurred on.
no setterinherited
-
broadcasterLogin
→ String
-
Login name of the broadcaster.
no setterinherited
-
broadcasterName
→ String
-
Twitch Display Name of the broadcaster.
no setterinherited
-
copyWith
→ $TwitchExtensionTransactionCopyWith<TwitchExtensionTransaction>
-
no setterinherited
-
domain
→ String?
-
Set this field to twitch.ext + your extension ID.
no setterinherited
-
expiration
→ String?
-
Always empty since only unexpired products can be purchased.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
Unique identifier of the Bits in Extensions Transaction.
no setterinherited
-
productData
→ ProductData
-
Object representing the product acquired, as it looked at the time of the
transaction.
no setterinherited
-
productType
→ TwitchExtensionTransactionProductType
-
Enum of the product type. Currently only
TwitchExtensionTransactionProductType.bitsInExtension.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
timestamp
→ DateTime
-
UTC timestamp when this transaction occurred.
no setterinherited
-
userId
→ String
-
Twitch User ID of the user who generated the transaction.
no setterinherited
-
userLogin
→ String
-
Login name of the user who generated the transaction.
no setterinherited
-
userName
→ String
-
Twitch Display Name of the user who generated the transaction.
no setterinherited