TwitchMaxPerUserPerStreamSetting class

Annotations
  • @freezed

Constructors

TwitchMaxPerUserPerStreamSetting({required bool isEnabled, required int maxPerUserPerStream})
const
factory
TwitchMaxPerUserPerStreamSetting.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TwitchMaxPerUserPerStreamSettingCopyWith<TwitchMaxPerUserPerStreamSetting>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
no setterinherited
maxPerUserPerStream → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited